Welcome to anyvc's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   about.rst
   workdir/index
   repo/index
   backends/index
   internals/index
   roadmap
   testing/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

